@@ -3,7 +3,7 @@
 
 import sys
 from functools import wraps
-from Naked.commandline import Command
+from Naked.toolshed.shell import Environment
 
 def print_scratch(func):
     @wraps(func)
@@ -22,9 +22,10 @@ def run_scratchpad():
     # test3 = "Hey! It's Bengali ব য,and here is some more ২"
     # print(unicode(test2))
 
-    import subprocess
-    arguments = 'naked build'
-    return_code = subprocess.call(arguments, stdin=None, stdout=sys.stdout, stderr=None, shell=True)
+    env = Environment()
+    if (env.is_var('PATH')):
+        for i in env.get_split_var_list('PATH'):
+            print(i)
 
 
 if __name__ == '__main__':
